summaryrefslogtreecommitdiff
path: root/dfa.c
diff options
context:
space:
mode:
authorVern Paxson <vern@ee.lbl.gov>1993-08-24 20:37:11 +0000
committerVern Paxson <vern@ee.lbl.gov>1993-08-24 20:37:11 +0000
commit4e27b497e883e60246e4daa4cc4208072dcebc30 (patch)
tree20bcab38f48c9dcec90aaa1028d2bc9200e87f84 /dfa.c
parentee15993b3542238e82492f7d17d33de312ae6c6e (diff)
"backtracking" -> "backing up"
Diffstat (limited to 'dfa.c')
-rw-r--r--dfa.c20
1 files changed, 10 insertions, 10 deletions
diff --git a/dfa.c b/dfa.c
index 7ffe263..b323336 100644
--- a/dfa.c
+++ b/dfa.c
@@ -42,38 +42,38 @@ void sympartition PROTO((int[], int, int[], int[]));
int symfollowset PROTO((int[], int, int, int[]));
/* check_for_backtracking - check a DFA state for backtracking
*
* synopsis
- * void check_for_backtracking( int ds, int state[numecs] );
+ * void check_for_backing_up( int ds, int state[numecs] );
*
* ds is the number of the state to check and state[] is its out-transitions,
* indexed by equivalence class.
*/
-void check_for_backtracking( ds, state )
+void check_for_backing_up( ds, state )
int ds;
int state[];
{
if ( (reject && ! dfaacc[ds].dfaacc_set) ||
(! reject && ! dfaacc[ds].dfaacc_state) )
{ /* state is non-accepting */
- ++num_backtracking;
+ ++num_backing_up;
- if ( backtrack_report )
+ if ( backing_up_report )
{
- fprintf( backtrack_file,
+ fprintf( backing_up_file,
"State #%d is non-accepting -\n", ds );
/* identify the state */
- dump_associated_rules( backtrack_file, ds );
+ dump_associated_rules( backing_up_file, ds );
/* Now identify it further using the out- and
* jam-transitions.
*/
- dump_transitions( backtrack_file, state );
+ dump_transitions( backing_up_file, state );
- putc( '\n', backtrack_file );
+ putc( '\n', backing_up_file );
}
}
}
@@ -689,7 +689,7 @@ void ntod()
}
if ( ds > num_start_states )
- check_for_backtracking( ds, state );
+ check_for_backing_up( ds, state );
if ( nultrans )
{
@@ -42,38 +42,38 @@ void sympartition PROTO((int[], int, int[], int[]));
int symfollowset PROTO((int[], int, int, int[]));
-/* check_for_backtracking - check a DFA state for backtracking
+/* check_for_backing_up - check a DFA state for backing up
*
* synopsis